Stan Math Library: stan::math::container_view< std::vector< Eigen::Matrix< T1, R, C > >, Eigen::Matrix< T2, R, C > > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | List of all members
stan::math::container_view< std::vector< Eigen::Matrix< T1, R, C > >, Eigen::Matrix< T2, R, C > > Class Template Reference

Template specialization for matrix view of array y with scalar type T2 with shape equal to x. More...

`#include <container_view.hpp>`

## Public Member Functions
| container_view (const std::vector< Eigen::Matrix< T1, R, C > > &x, T2 *y)
| Constructor assumes all matrix elements in std::vector are of same dimension. More...
Eigen::Map< Eigen::Matrix< T2, R, C > > & | operator[] (int i)
| operator[](int i) returns matrix view of scalartype T2 at appropriate index i in array y More...

## Detailed Description

### template<typename T1, typename T2, int R, int C>
class stan::math::container_view< std::vector< Eigen::Matrix< T1, R, C > >, Eigen::Matrix< T2, R, C > >

Template specialization for matrix view of array y with scalar type T2 with shape equal to x.

Template Parameters

  T1 | scalar type of input vector of matrices
  T2 | scalar type of matrix view
  R | rows of input matrix and view
  C | columns of input matrix and view

Definition at line 91 of file container_view.hpp.

## Constructor & Destructor Documentation

template<typename T1 , typename T2 , int R, int C>

stan::math::container_view< std::vector< Eigen::Matrix< T1, R, C > >, Eigen::Matrix< T2, R, C > >::container_view | ( | const std::vector< Eigen::Matrix< T1, R, C > > & | x,
|  | T2 * | y
| ) |  |
| inline

Constructor assumes all matrix elements in std::vector are of same dimension.

Initializes y_view as 1x1 matrix because no nullary constructor for Eigen::Map

Parameters

  x | input matrix
  y | underlying array

Definition at line 104 of file container_view.hpp.

## Member Function Documentation

template<typename T1 , typename T2 , int R, int C>

Eigen::Map<Eigen::Matrix<T2, R, C> >& stan::math::container_view< std::vector< Eigen::Matrix< T1, R, C > >, Eigen::Matrix< T2, R, C > >::operator[] | ( | int | i | ) |
| inline

operator[](int i) returns matrix view of scalartype T2 at appropriate index i in array y

Definition at line 119 of file container_view.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/mat/meta/container_view.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.